==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/d8/d72/newgrf__text_8h.js <==
var newgrf__text_8h =
[
    [ "LanguageMap", "d7/dbb/structLanguageMap.html", "d7/dbb/structLanguageMap" ],
    [ "Mapping", "d0/d87/structLanguageMap_1_1Mapping.html", "d0/d87/structLanguageMap_1_1Mapping" ],
    [ "AddGRFString", "d8/d72/newgrf__text_8h.html#a6bc5f40c1503f444aca6d8ca51553d71", null ],
    [ "AddGRFTextToList", "d8/d72/newgrf__text_8h.html#ae298adb8d62305573a118e66c15b9d14", null ],
    [ "AddGRFTextToList", "d8/d72/newgrf__text_8h.html#a0b08d72bb75a1770dfa8c09082e01de7", null ],
    [ "AddGRFTextToList", "d8/d72/newgrf__text_8h.html#a8dba7e99e697b3abf3fb0efc37136b51", null ],
    [ "CheckGrfLangID", "d8/d72/newgrf__text_8h.html#a682e06efb77be24dea2d4e91c747855f", null ],
    [ "CleanUpGRFText", "d8/d72/newgrf__text_8h.html#a65526e126f04c2872d1a2e568bccf8ce", null ],
    [ "CleanUpStrings", "d8/d72/newgrf__text_8h.html#a10b77b5eea25ea2aedc396e9dc8e4965", null ],
    [ "CreateTextRefStackBackup", "d8/d72/newgrf__text_8h.html#a89dbe73cf8fcd146d3f2af19006a199a", null ],
    [ "DuplicateGRFText", "d8/d72/newgrf__text_8h.html#aa56c6cb5e898ebe6e3439af01c857d7b", null ],
    [ "GetGRFStringFromGRFText", "d8/d72/newgrf__text_8h.html#ac7068c0b7a0880596555c1d5a37fb57f", null ],
    [ "GetGRFStringID", "d8/d72/newgrf__text_8h.html#a758f6f849cec29a20a61cea333927c38", null ],
    [ "GetGRFStringPtr", "d8/d72/newgrf__text_8h.html#aa145cd8b855272f5c15296521d82d35b", null ],
    [ "RemapNewGRFStringControlCode", "d8/d72/newgrf__text_8h.html#a0a6b4b3d02397c0883633b6c0a4b8fe8", null ],
    [ "RestoreTextRefStackBackup", "d8/d72/newgrf__text_8h.html#aa003c5a7296b95aa9831fc482d3da379", null ],
    [ "RewindTextRefStack", "d8/d72/newgrf__text_8h.html#ad8d287f160b26a69002c9d8dc02fd47a", null ],
    [ "SetCurrentGrfLangID", "d8/d72/newgrf__text_8h.html#ad6fd2a35d352f014a0602c4127729b86", null ],
    [ "StartTextRefStackUsage", "d8/d72/newgrf__text_8h.html#a549834ba4facab9d38575b81d4475609", null ],
    [ "StopTextRefStackUsage", "d8/d72/newgrf__text_8h.html#afb2ed80978cd7fcbc9a98dce4360e1ee", null ],
    [ "TranslateTTDPatchCodes", "d8/d72/newgrf__text_8h.html#a96d1a86a2085f830bb7ab75f0424b8ac", null ],
    [ "UsingNewGRFTextStack", "d8/d72/newgrf__text_8h.html#aa096d9107d1befe781f8a3d00d848e10", null ],
    [ "NFO_UTF8_IDENTIFIER", "d8/d72/newgrf__text_8h.html#ae3590b0e951c7805a3ffa064ebb6afbe", null ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/d8/d72/newgrf__text_8h.js <==
var newgrf__text_8h =
[
    [ "GRFText", "de/d2d/structGRFText.html", "de/d2d/structGRFText" ],
    [ "LanguageMap", "d7/dbb/structLanguageMap.html", "d7/dbb/structLanguageMap" ],
    [ "Mapping", "d0/d87/structLanguageMap_1_1Mapping.html", "d0/d87/structLanguageMap_1_1Mapping" ],
    [ "GRFTextList", "d8/d72/newgrf__text_8h.html#a939bfb1c2d981c49fa717824f138802f", null ],
    [ "GRFTextWrapper", "d8/d72/newgrf__text_8h.html#a937f34d1b21cf9f9ed9973601dc7ca5d", null ],
    [ "AddGRFString", "d8/d72/newgrf__text_8h.html#a6bc5f40c1503f444aca6d8ca51553d71", null ],
    [ "AddGRFTextToList", "d8/d72/newgrf__text_8h.html#aa31f686e49bfea9f77894dc02e1f1c22", null ],
    [ "AddGRFTextToList", "d8/d72/newgrf__text_8h.html#ae2b9bbb010e80084c35ab690ba0a488a", null ],
    [ "AddGRFTextToList", "d8/d72/newgrf__text_8h.html#ac91f4656ceaad876b768a563ef8457fb", null ],
    [ "CheckGrfLangID", "d8/d72/newgrf__text_8h.html#a682e06efb77be24dea2d4e91c747855f", null ],
    [ "CleanUpStrings", "d8/d72/newgrf__text_8h.html#a10b77b5eea25ea2aedc396e9dc8e4965", null ],
    [ "CreateTextRefStackBackup", "d8/d72/newgrf__text_8h.html#a89dbe73cf8fcd146d3f2af19006a199a", null ],
    [ "GetGRFStringFromGRFText", "d8/d72/newgrf__text_8h.html#aac2478607f0ccc0f7f2422e9789984ed", null ],
    [ "GetGRFStringFromGRFText", "d8/d72/newgrf__text_8h.html#af97909da95b704815d4ab9e7c9dbaf2a", null ],
    [ "GetGRFStringID", "d8/d72/newgrf__text_8h.html#a758f6f849cec29a20a61cea333927c38", null ],
    [ "GetGRFStringPtr", "d8/d72/newgrf__text_8h.html#aa145cd8b855272f5c15296521d82d35b", null ],
    [ "RemapNewGRFStringControlCode", "d8/d72/newgrf__text_8h.html#a0a6b4b3d02397c0883633b6c0a4b8fe8", null ],
    [ "RestoreTextRefStackBackup", "d8/d72/newgrf__text_8h.html#aa003c5a7296b95aa9831fc482d3da379", null ],
    [ "RewindTextRefStack", "d8/d72/newgrf__text_8h.html#ad8d287f160b26a69002c9d8dc02fd47a", null ],
    [ "SetCurrentGrfLangID", "d8/d72/newgrf__text_8h.html#ad6fd2a35d352f014a0602c4127729b86", null ],
    [ "StartTextRefStackUsage", "d8/d72/newgrf__text_8h.html#aba70b7b9bdb5875377e2fc002530a331", null ],
    [ "StopTextRefStackUsage", "d8/d72/newgrf__text_8h.html#afb2ed80978cd7fcbc9a98dce4360e1ee", null ],
    [ "TranslateTTDPatchCodes", "d8/d72/newgrf__text_8h.html#ab336099ddcb32c5e5b7daef237da2a6b", null ],
    [ "UsingNewGRFTextStack", "d8/d72/newgrf__text_8h.html#aa096d9107d1befe781f8a3d00d848e10", null ],
    [ "NFO_UTF8_IDENTIFIER", "d8/d72/newgrf__text_8h.html#ae3590b0e951c7805a3ffa064ebb6afbe", null ]
];
